@@ -16,9 +16,10 @@ Example:
 """
 from __future__ import annotations
 
-from typing import List
+from typing import List, Optional
 
 from rdflib import Graph, Namespace, RDF, URIRef
+from skolemizer import Skolemizer
 
 from .dataset import Dataset
 from .resource import Resource
@@ -47,9 +48,13 @@ class DataService(Resource):
     _servesdatasets: List[Dataset]
     _media_types: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits DataService with default values."""
         super().__init__()
+
+        if identifier:
+            self.identifier = identifier
+
         self._type = DCAT.DataService
         self.servesdatasets = []
         self.media_types = []
@@ -93,6 +98,9 @@ class DataService(Resource):
     # -
     def _to_graph(self: DataService) -> Graph:
 
+        if not getattr(self, "identifier", None):
+            self.identifier = Skolemizer.add_skolemization()
+
         super(DataService, self)._to_graph()
 
         self._g.add((URIRef(self.identifier), RDF.type, self._type))
@@ -128,6 +136,10 @@ class DataService(Resource):
     def _servesdatasets_to_graph(self: DataService) -> None:
 
         for dataset in self._servesdatasets:
+
+            if not getattr(dataset, "identifier", None):
+                dataset.identifier = Skolemizer.add_skolemization()
+
             self._g.add(
                 (
                     URIRef(self.identifier),
